### MERGE spain DATA Edited by FH
rm(list = ls())
source("format.fun.R")
library(reshape)

dir.create("../../output/process/Spain", recursive=TRUE,showWarnings=FALSE)

######################### READ DATA read individuals tree data 
data.spain <- read.table("../../data/raw/Spain/Tree_data_SFI_aug13_alldata.txt", 
    header = TRUE, stringsAsFactors = FALSE, sep = "\t")
    
###################################### MASSAGE TRAIT DATA Compute maximum height per species plus sd from observed
###################################### height to add variables to the traits data base Because we have two heights,
###################################### then take the max of the two heights and then bootstrap
res.quant.boot <- t(sapply(levels(factor(data.spain[["SP_code"]])), FUN = f.quantile.boot, 
    R = 1000, x = log10(apply(data.spain[, c("ht1", "ht2")], 1, max, na.rm = T)), 
    fac = factor(data.spain[["SP_code"]])))
## create data base
data.max.height <- data.frame(sp = rownames(res.quant.boot), Max.height.mean = res.quant.boot[, 
    1], Max.height.sd = res.quant.boot[, 2], Max.height.nobs = res.quant.boot[, 3], stringsAsFactors =FALSE)
rm(res.quant.boot)
write.csv(data.max.height, file = "../../output/process/Spain/data.max.height.csv")  ## I was planning to save processed data in that folder


################################## FORMAT INDIVIDUAL TREE DATA
data.spain$G <- data.spain[["adbh"]] ## diameter growth in mm per year
data.spain$year <- data.spain[["years"]]; data.spain$years <- NULL; ## number of year between measurement
data.spain$D <- data.spain[["dbh1"]]/10  ## diameter in mm convert to cm
data.spain$dead <- as.numeric(data.spain[["Life_status"]] == "dead")  ## dummy variable for dead tree 0 alive 1 dead
data.spain$sp <- paste("sp",(data.spain[["SP_code"]]) ,sep=".") ## species code
data.spain$sp.name <-  data.spain[["SP_name"]]; data.spain$SP_name <- NULL
data.spain$plot <- (data.spain[["Plot_ID_SFI"]]); data.spain$Plot_ID_SFI <- NULL ## plot code
data.spain$cluster <- rep(NA,nrow(data.spain)) ## cluster code missing here
data.spain$htot <- data.spain[["ht1"]]  ## height of tree in m
data.spain$tree.id <- data.spain$Tree_ID_SFI; data.spain$Tree_ID_SFI <- NULL ## tree unique id
data.spain$obs.id <- as.character(1:nrow(data.spain)) ## obs uniquue id; could use tree unique id here since there is only one row per tree
data.spain$census <- rep(1,nrow(data.spain)) ## only one census in spain
data.spain$weights <- as.vector(1/(pi * (data.spain[["R1"]])^2)) ## weights in 1/m^2
#################
#### change coordinates system of x y to be in lat long WGS84
library(sp)
library(dismo)
library(rgdal)
data.sp <- data.spain[, c("tree.id", "CX", "CY")]
coordinates(data.sp) <- c("CX", "CY")  # define x y
proj4string(data.sp) <- CRS("+init=epsg:23030")  # define projection system of our data ## EPSG CODE 23030 ED50 / UTM zone 30N
summary(data.sp)
detach(package:rgdal)
data.sp2 <- spTransform(data.sp, CRS("+init=epsg:4326"))  ## change projection in WGS84 lat lon
data.spain$Lon <- coordinates(data.sp2)[, "CX"]
data.spain$Lat <- coordinates(data.sp2)[, "CY"]
## ## plot on world map
## library(rworldmap)
## newmap <- getMap(resolution = 'coarse')
## # different resolutions available plot(newmap)
## points(data.sp2,cex=0.2,col='red')
rm(data.sp, data.sp2)
###################### ECOREGION merge greco to have no ecoregion with low number of observation
greco <- read.csv(file = "../../data/raw/Spain/R_Ecoregion.csv", header = T)
greco <- greco[, c("Plot_ID_SFI", "BIOME", "eco_code")]
greco2 <- greco[!duplicated(greco$Plot), ]; 
colnames(greco2) <- c("plot", "biome", "ecocode")
rm(greco)
data.spain <- merge(data.spain, greco2, by = "plot")
rm(greco2)
table(data.spain$ecocode)
## There's an eco-region with no code, and one with < 1000 sites The former we could drop as they were on the border of Spain
# ### PLOT ECOREGION
# library(RColorBrewer)
# mycols <- brewer.pal(10, "Set3")
# ecoreg <- unclass(data.spain$eco_code)
# 
# pdf("./figs/ecoregion.spain.pdf")
# plot(data.spain[["CX"]][order(ecoreg)], data.spain[["CY"]][order(ecoreg)], pty = ".", 
#     cex = 0.2, col = rep(mycols, as.vector(table(ecoreg))))
# legend("topleft", col = mycols, legend = levels(data.spain$eco_code), pch = rep(19, 
#     length(levels(ecoreg))), cex = 2)
# points(data.spain[["CX"]][ecoreg == 9], data.spain[["CY"]][ecoreg == 9], pty = ".", 
#     cex = 0.5, col = "black")
# ## Highlight the 'rare' ecoregions
# points(data.spain[["CX"]][ecoreg == 1], data.spain[["CY"]][ecoreg == 1], pty = ".", 
#     cex = 0.5, col = "black")
# ## Highlight the 'rare' ecoregions PA1219 looks to be similar to PA1209, merge
# ## them together
# dev.off()
## merge
data.spain$ecocode.merged <- combine_factor(data.spain$ecocode, c(1:8, 6, 9))
data.spain <- data.spain[-which(data.spain$ecocode.merged == ""), ]
data.spain$ecocode.merge <- as.character(factor(data.spain$ecocode.merged))
# PLOT of  MERGED ECOREGION
# mycols <- brewer.pal(9, "Set3")
# plot(data.spain[["CX"]][order(data.spain$eco_codemerged)], data.spain[["CY"]][order(data.spain$eco_codemerged)], pty = ".", 
#     cex = 0.2, col = rep(mycols, as.vector(table(data.spain$eco_codemerged))))
# legend("topleft", col = mycols, legend = levels(data.spain$eco_codemerged), pch = rep(19, 
#     length(levels(data.spain$eco_codemerged))), cex = 2)
###################### PERCENT DEAD variable percent dead/cannot do with since dead variable is
###################### missing compute numer of dead per plot to remove plot with disturbance
perc.dead <- tapply(data.spain[["dead"]], INDEX = data.spain[["plot"]], FUN = function.perc.dead2)
table(data.spain$dead)
data.spain <- merge(data.spain, data.frame(plot = as.numeric(names(perc.dead)), perc.dead = perc.dead, stringsAsFactors =FALSE), 
                    sort = FALSE, by = "plot")
########################################################### PLOT SELECTION FOR THE ANALYSIS 
## Remove data with mortality == 1 or 2
data.spain <- subset(data.spain,
                     subset = (data.spain[["Mortality_Cut"]] == 0 |
                               data.spain[["Mortality_Cut"]] ==  ""))
colnames(data.spain)[colnames(data.spain) %in% c("mat", "pp", "PET")] <- c("MAT", 
    "PP", "PET")
data.spain$ecocode <- NULL
colnames(data.spain)[names(data.spain) == "ecocode.merged"] <- c("ecocode")
vec.abio.var.names <- c("MAT", "PP", "PET")
vec.basic.var <- c("obs.id","tree.id", "sp", "sp.name", "cluster","plot", "ecocode", "D", "G", "dead", 
    "year", "htot", "Lon", "Lat", "perc.dead","census","weights")
data.tree <- subset(data.spain, select = c(vec.basic.var, vec.abio.var.names))
write.csv(data.tree,file="../../output/process/Spain/data.tree.csv")
